@@ -297,7 +297,12 @@ class SoftLinx:
             else:
                 self.protocolSteps.append(step)
         # * Add .hso filename to manifest list
-        hso_filename = os.path.basename(filename)
+        if "\\" in filename:
+            hso_filename = filename.split("\\")[-1]
+        elif "/" in filename:
+            hso_filename = filename.split("/")[-1]
+        else:
+            hso_filename = filename
         self.addToManifest(hso_filename)
 
         return step
@@ -358,7 +363,7 @@ class SoftLinx:
             "Description": "",
             "SLXId": "62c47122-48c6-413a-a41b-9ff35a0489fc",
             "ToolTip": "",
-            "isActive": isActive,
+            "isActive": str(isActive),
             "system": "Hidex",
             "args": [],
         }
@@ -375,7 +380,7 @@ class SoftLinx:
             "Description": "",
             "SLXId": "9d060013-be01-403d-b15a-b0ce9da34cb3",
             "ToolTip": "",
-            "isActive": isActive,
+            "isActive": str(isActive),
             "system": "Hidex",
             "args": [],
         }
@@ -584,8 +589,8 @@ class SoftLinx:
                 + softlinx_filename
                 + "\n"
             )
-            file.write("WinActivate, SoftLinx V\n")
             file.write("Sleep, 5000\n")
+            file.write("WinActivate, SoftLinx V\n")
             file.write("MouseClick, Left, 300, 45\n")
             file.write("Sleep, 1000\n")
             file.write('if WinActive("Not Saved") {\n')
